Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2046)

Unified Diff: content/common/service_worker/service_worker_client_info.h

Issue 988063004: Use UUID for ServiceWorker Client identifier (2/3, chromium) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: addressed comments Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/service_worker/service_worker_client_info.h
diff --git a/content/common/service_worker/service_worker_client_info.h b/content/common/service_worker/service_worker_client_info.h
index 7a299509d5debe1d3d892d3f128a4dc684a98fe7..e21aa1552f955afadd17e1dc80b25b33be7e1165 100644
--- a/content/common/service_worker/service_worker_client_info.h
+++ b/content/common/service_worker/service_worker_client_info.h
@@ -15,8 +15,8 @@ namespace content {
// This class holds the information related to a service worker window client.
// It is the content/ equivalent of Blink's WebServiceWorkerClientInfo.
// An instance can be created empty or can be filed with the expected
// properties. Except for the client_id, it is preferred to use the constructor
// to fill the properties.
struct ServiceWorkerClientInfo {
ServiceWorkerClientInfo();
ServiceWorkerClientInfo(blink::WebPageVisibilityState page_visibility_state,
@@ -29,10 +29,10 @@ struct ServiceWorkerClientInfo {
bool IsEmpty() const;
// Returns whether the instance is valid. A valid instance is not empty and
- // has a valid client_id.
+ // has a valid client_uuid.
bool IsValid() const;
- int client_id;
+ std::string client_uuid;
blink::WebPageVisibilityState page_visibility_state;
bool is_focused;
GURL url;
@@ -15,8 +15,8 @@ namespace content {
// It is the content/ equivalent of Blink's WebServiceWorkerClientInfo.
// An instance can be created empty or can be filed with the expected
-// properties. Except for the client_id, it is preferred to use the constructor
-// to fill the properties.
+// properties. Except for the client_uuid, it is preferred to use the
+// constructor to fill the properties.
struct ServiceWorkerClientInfo {
ServiceWorkerClientInfo();
« no previous file with comments | « content/browser/service_worker/service_worker_version.cc ('k') | content/common/service_worker/service_worker_client_info.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698